@@ -86,13 +86,14 @@ class SaunterTestCase(BaseTestCase):
         """
         self.verificationErrors = []
         self.cf = saunter.ConfigWrapper.ConfigWrapper().config
+        self.cf.set("Saunter", "name", method.__name__)
         self.config = self.cf
         if self.cf.getboolean("SauceLabs", "ondemand"):
             desired_capabilities = {
                 "platform": self.cf.get("SauceLabs", "os"),
                 "browserName": self.cf.get("SauceLabs", "browser"),
                 "version": self.cf.get("SauceLabs", "browser_version"),
-                "name": self._testMethodName
+                "name": method.__name__
             }
             if desired_capabilities["browserName"][0] == "*":
                 desired_capabilities["browserName"] = desired_capabilities["browserName"][1:]
@@ -125,9 +126,6 @@ class SaunterTestCase(BaseTestCase):
         self.verificationErrors = []
         self.matchers = Matchers(self.driver, self.verificationErrors)
         
-        if self.cf.getboolean("Saunter", "use_implicit_wait"):
-            self.driver.implicitly_wait(self.cf.getint("Saunter", "implicit_wait"))
-        
         if self.cf.getboolean("SauceLabs", "ondemand"):
             self.sauce_session = self.driver.session_id
             
